@@ -5,7 +5,7 @@ test_that("Horizon plot has the correct content", {
   
   data(spas)
   sep = gr_separate(spas, params = gr_get_params(reg = 'center'))
-  plt = gr_plot_hori(sep, years = 1960:1980)
+  plt = suppressWarnings(gr_plot_hori(sep, years = 1960:1980))
   
   expect_s3_class(plt, 'ggplot')
   expect_type(plt, 'list')
